rename "synopsis" to "usage".
[paraslash.git] / server.h
index ba9b39e45359ef08deba2c2ead21d4acfc4616b2..dd5184f4ca5beb3d6fbdeeaec6f2000a5409a80b 100644 (file)
--- a/server.h
+++ b/server.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2006 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2007 Andre Noll <maan@systemlinux.org>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
 /** \file server.h common server data structures */
 
 #include "para.h"
+#include <openssl/pem.h>
 
-
-/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
+/** size of the selector_info and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 
-/**
- * permission flags that can be set individually for any server command
- *
- * - DB_READ: command reads from the database
- * - DB_WRITE: command changes the contents of the database
- * - AFS_READ: command reads information about the current audio stream
- * - AFS_WRITE: command changes the current audio stream
- */
-enum {DB_READ = 1, DB_WRITE = 2, AFS_READ = 4, AFS_WRITE = 8};
-
-/**
- * data needed to authenticate the user
- */
-struct user{
-/** the username */
-       char name[MAXLINE];
-/** full path to the public RSA key */
-       char pubkey_file[_POSIX_PATH_MAX];
-/** the privileges of this user */
-       unsigned int perms;
-};
-
 /**
  * defines one command of para_server
  */
 struct server_command {
 /** the name of the command */
-       char *name;
+       const char *name;
 /** pointer to the function that handles the command */
        int (*handler)(int, int, char **);
 /** the privileges a user must have to execute this command */
        unsigned int perms;
 /** one-line description of the command */
-       char *description;
+       const char *description;
 /** summary of the command line options */
-       char *synopsis;
+       const char *usage;
 /** the long help text */
-       char *help;
+       const char *help;
 };
 
 /** holds the arguments for the para_server's sender command */
@@ -104,9 +82,9 @@ struct misc_meta_data{
 /* the number of the current audio format */
        int audio_format;
 /** the "old" status flags -- commands may only read them */
-       unsigned int afs_status_flags;
+       unsigned int vss_status_flags;
 /** the new status flags -- commands may set them **/
-       unsigned int new_afs_status_flags;
+       unsigned int new_vss_status_flags;
 /** the number of data chunks sent for the current audio file */
        long unsigned chunks_sent;
 /** the number of chunks this audio file contains */
@@ -139,18 +117,17 @@ struct misc_meta_data{
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
-/** a string that gets filled in by the current database tool */
-       char dbinfo[MMD_INFO_SIZE];
-/** the number if the current database tool */
-       int dbt_num;
-/** commands set this to non-zero to request a database tool change */
-       int dbt_change;
+/** a string that gets filled in by the current audio file selector */
+       char selector_info[MMD_INFO_SIZE];
+/** the number if the current audio file selector */
+       int selector_num;
+/** commands set this to non-zero to change the current selector */
+       int selector_change;
 /** used by the sender command */
        struct sender_command_data sender_cmd_data;
-/** each dbtool has its private data pointer */
-       void *private_dbtool_data[NUM_DBTOOLS];
 };
 
+extern struct server_args_info conf;
 
 int handle_connect(int fd, struct sockaddr_in *addr);
 void mmd_unlock(void);